@@ -26,7 +26,7 @@ pub mod execute_cost_table;
 pub mod genesis_utils;
 pub mod hardened_unpack;
 pub mod hashed_transaction;
-pub mod inline_spl_token;
+pub mod inline_spl_token_v2_0;
 pub mod instruction_recorder;
 pub mod loader_utils;
 pub mod log_collector;
